Nodeapps Commands
Use commands with the nodeapps keyword to add, modify, manage environment variables for, list the configuration of, enable, disable, start, stop, obtain the status of, and remove node applications.
srvctl add nodeapps
Adds a node application configuration to the specified node.
Syntax
Use this command with one the following syntax models, specifying either a specific node and VIP or a specific subnet and netmask:
srvctl add nodeapps {-node node_name -address {vip_name |
ip_address}/netmask[/if1[|if2|..]] [-skip]}
[-emport em_port] [-onslocalport ons_local_port] [-onsremoteport ons_remote_port]
[-remoteservers hostname[:port][,hostname[:port]]
[-clientdata client_data_file [-scanclient]] [-pingtarget "pingtarget_list"] [-vipless] [-verbose]
srvctl add nodeapps -subnet subnet/netmask[/if1[|if2|...]] [-emport em_port]
[-onslocalport ons_local_port] [-onsremoteport ons_remote_port]
[-remoteservers hostname[:port][,hostname[:port]]
[-clientdata client_data_file [-scanclient]] [-pingtarget "pingtarget_list"] [-vipless] [-verbose]
Parameters
Table: srvctl add nodeapps Command Parameters
| Parameter | Description |
|---|---|
-node node_name | The name of the node on which you want to create the node application. Node name is optional and unnecessary if you run the command on the local node. |
-address { vip_name | ip_address }/ netmask [/ if1 [| if2 |..]]} | This specification creates a traditional VIP node application on the specified node. Note: You must use this parameter for upgrade configurations and new, non-DHCP configurations. |
-skip | Specify this parameter to skip checking the reachability of the VIP address. |
-subnet subnet / netmask [/ if1 [| if2 |...]] | Creates a DHCP subnet. If you do not specify any interface names, then the VIPs use any interface on the given subnet. |
-emport em_port | Local port on which Oracle Enterprise Manager listens. The default port is 2016. |
-onslocalport ons_local_port | The Oracle Notification Service daemon listener port on its node. If you do not specify this value, the Oracle Notification Service daemon listener port defaults to 6100. Note: The local port and remote port must each be unique. |
-onsremoteport ons_remote_port | The port number for remote Oracle Notification Service daemon connections. If you do not specify a port number, the default value of 6200 is used for the Oracle Notification Service remote port. Note: The local port and remote port must each be unique. |
-remoteservers hostname [: port ] | A list of hostname [: port ] pairs for Oracle Notification Service daemons on servers that are not in the cluster. |
-clientdata client_data_file | Optionally, you can specify the file with a wallet to import, or an empty string to delete a wallet used for SSL to secure Oracle Notification Service communication. If you want to use a custom certificate, then add your custom certificate to an auto-login Oracle wallet using the /wallet_directory/Oracle_wallet_name/custom_certificate_name.sso |
-scanclient | Optionally, you can specify SCAN client cluster name. |
-pingtarget " pingtarget_list " | Optionally, you can specify a comma-delimited list of IPs or host names enclosed in double quotation marks ("") to ping. |
-vipless | Specify this option to add a network without node VIP addresses. |
-verbose | Verbose output. |
Usage Notes
- On Linux and UNIX systems, you must be logged in as
rootand on Windows, you must be logged in as a user with Administrator privileges to run this command. - This command is only available with Oracle Clusterware.
Example
An example of this command is:
# srvctl add nodeapps -node crmnode1 -address 1.2.3.4/255.255.255.0
Related Topics
srvctl config nodeapps
Displays the VIP configuration for each node in the cluster.
Note:
This command is only available with Oracle Clusterware.
Syntax
srvctl config nodeapps [-viponly] [-onsonly] [-exportfile file_name]
Usage Notes
Use -viponly to display the VIP address configuration. Use -onsonly to display the Oracle Notification Service configuration.
The -exportfile specifies the output file to which the resource configuration will be exported in JSON format for backup or resource re-creation purposes.
Example
An example of this command is:
$ srvctl config nodeapps -viponly -onsonly
srvctl disable nodeapps
Disables node applications on all nodes in the cluster.
Syntax
srvctl disable nodeapps [-onsonly] [-adminhelper] [-verbose]
Parameters
Table: srvctl disable nodeapps Command Parameters
| Parameter | Description |
|---|---|
-onsonly | Optionally, you can use this parameter to disable only the Oracle Notification Service (ONS). |
-adminhelper | Optionally, you can use this parameter to disable the Administrator helper only. |
-verbose | Optionally, you can use this parameter to display detailed output. |
Usage Notes
You can only use this parameter with Oracle Clusterware.
Example
The following example disables ONS:
$ srvctl disable nodeapps -onsonly -verbose
srvctl enable nodeapps
Enables the node applications on all nodes in the cluster.
Syntax
srvctl enable nodeapps [-onsonly] [-adminhelper] [-verbose]
Parameters
Table: srvctl enable nodeapps Command Parameters
| Parameter | Description |
|---|---|
-onsonly | Optionally, you can use this parameter to disable only the Oracle Notification Service (ONS). |
-adminhelper | Optionally, you can use this parameter to enable the Administrator helper only. |
-verbose | Optionally, you can use this parameter to display detailed output. |
Usage Notes
You can only use this command with Oracle Clusterware.
Example
The following example enables ONS:
$ srvctl enable nodeapps -onsonly -verbose
srvctl getenv nodeapps
Displays the environment variables for the node application configurations.
Syntax
srvctl getenv nodeapps [-viponly] [-onsonly] [-envs "name_list"]
Parameters
Table: srvctl getenv nodeapps Command Parameters
| Parameter | Description |
|---|---|
-viponly | Optionally, you can use this parameter to display the VIP address configuration. |
-onsonly | Optionally, you can use this parameter to isplay the Oracle Notification Service configuration. |
-envs " name_list " | Optionally, you can specify a comma-delimited list of the names of environment variables enclosed in double quotation marks ( If you do not use this parameter, then SRVCTL displays the values of all environment variables associated with the node applications. |
Usage Notes
You can only use this command with Oracle Clusterware.
Example
The following example lists all environment variables for the node applications:
$ srvctl getenv nodeapps -viponly
srvctl modify nodeapps
Modifies the configuration for a node application.
Syntax
Use this command with one of the following syntax models, specifying either a specific node and VIP or a specific subnet and netmask:
srvctl modify nodeapps {[-node node_name -address {vip_name|vip_address}/
netmask[/if1[|if2|...]] [-skip]} [-nettype network_type] [-emport em_port]
[-onslocalport ons_local_port] [-onsremoteport ons_remote_port]
[-remoteservers host:[port][,...]] [-verbose]
[-clientdata file] [-pingtarget "ping_target_list"]
srvctl modify nodeapps [-subnet subnet/netmask[/if1[|if2|...]]]
[-nettype network_type] [-emport em_port]
[-onslocalport ons_local_port] [-onsremoteport ons_remote_port]
[-remoteservers host:[port][,host:port,...]] [-verbose]
[-clientdata file] [-pingtarget "ping_target_list"]
Parameters
Table: srvctl modify nodeapps Command Parameters
| Parameter | Description |
|---|---|
-node node_name | Specify the name of the node on which the node application you want to modify resides. |
-address { vip_name | vip_address }/ netmask [/ if1 [| if2 |...]] | Specify a node-level virtual IP name or address. The address specified by name or IP must match the subnet number of the default network. Note: You must use this parameter for upgrade configurations and new non-DHCP configurations |
-skip | Optionally, you can use this parameter to skip checking the reachability of the VIP address. |
-subnet subnet / netmask [/ if1 [| if2 |...]] | Alternative to specifying a node name and address, you can specify a subnet number for the public network. The netmask and interfaces you specify, if any, change those of the default network. Additionally, if you specify a value for the netmask option, then you need only specify it for the first node on each network. |
-nettype network_type | Optionally, you can change the network server type to static, dhcp, or mixed. |
-emport em_port | Optionally, you can change the local port on which Oracle Enterprise Manager listens. Note: You can also modify this attribute using Online Resource Attribute Modification. |
-onslocalport ons_local_port | Optionally, you can change the port on which the Oracle Notification Service daemon listens for local client connections. Notes:
|
-onsremoteport ons_remote_port | Optionally, you can change the port on which the Oracle Notification Service daemon listens for connections from remote hosts. Notes:
|
-remoteservers host :[ port ][,...] | Optionally, you can modify the comma-delimited list of host :[ port pairs of remote hosts that are part of the Oracle Notification Service network but are not part of the cluster. If you do not specify a port for a remote host, then the utility uses the value you specified for ons_remote_port. |
-clientdata file | Optionally, you can specify the file with a wallet to import, or an empty string to delete a wallet used for SSL to secure Oracle Notification Service communication. Note: You must manually restart the ONS server after updating the ONS security certificate using this parameter. |
-pingtarget " ping_target_list " | Optionally, you can specify a comma-delimited list of IPs or host names enclosed in double quotation marks ( "" ) to ping. |
-verbose | Optionally, you can use this parameter to display detailed output. |
Usage Notes
You can only use this command with Oracle Clusterware.
Example
The following example changes the nodeapps resource on mynode1 to use the application VIP of 100.200.300.40 with a subnet mask of 255.255.255.0 on the network interface eth0:
$ srvctl modify nodeapps -node mynode1 -addr 100.200.300.40/255.255.255.0/eth0
Note:
You must manually restart the ONS server after updating the ONS security certificate using the -clientdata parameter.
srvctl remove nodeapps
Removes the node application configuration.
Syntax
srvctl remove nodeapps [-force] [-noprompt] [-verbose]
Parameters
Table: srvctl remove nodeapps Command Parameters
| Parameter | Description |
|---|---|
-force | Optionally, you can use this parameter to forcibly remove node application configurations, regardless of any dependencies. |
-noprompt | Optionally, you can use this parameter to suppress prompts. |
-verbose | Optionally, you can use this parameter to display detailed output. |
Usage Notes
- You can only use this command with Oracle Clusterware.
- You must have full administrative privileges to run this command. On Linux and UNIX systems, you must be logged in as
rootand on Windows systems, you must be logged in as a user with Administrator privileges.
srvctl setenv nodeapps
Sets the environment variables for the node application configurations.
Syntax
srvctl setenv nodeapps {-envs "name=val[,...]" | -env "name=val"}
[-viponly] [-onsonly] [-verbose]
Parameters
Table: srvctl setenv nodeapps Command Parameters
| Parameter | Description |
|---|---|
-envs " name = val [,...]" | Use this parameter to specify a comma-delimited list of name-value pairs of environment variables enclosed in double quotation marks ( "" ). |
-env " name = val " | Alternatively, you can use this parameter to enable a single environment variable that is set to a value which contains commas or other special characters, enclosed in double quotation marks ( "" ). |
-viponly | Optionally, you can use this parameter to modify only the VIP configuration. |
-onsonly | Optionally, you can use this parameter to modify only the ONS daemon configuration. |
-verbose | Optionally, you can use this parameter to display detailed output. |
Usage Notes
You can only use this command with Oracle Clusterware.
Example
The following example sets the CLASSPATH environment variable for all node applications:
$ srvctl setenv nodeapps -env "CLASSPATH=/usr/local/jdk/jre/rt.jar" -verbose
srvctl start nodeapps
Starts node-level applications on a node or all nodes in the cluster.
Syntax
srvctl start nodeapps [-node node_name] [-onsonly] [-adminhelper] [-verbose]
Parameters
Table: srvctl start nodeapps Command Parameters
| Parameter | Description |
|---|---|
-node node_name | Optionally, you can specify a node on which to start node-level applications. If you do not use this parameter, then SRVCTL starts the node applications on all active nodes in the cluster. |
-onsonly | Optionally, you can use this parameter to disable only the Oracle Notification Service (ONS). |
-adminhelper | Optionally, you can use this parameter to start only an Administrator helper instead of all node applications. |
-verbose | Optionally, you can use this parameter to display detailed output. |
Usage Notes
You can only use this command with Oracle Clusterware.
srvctl status nodeapps
Displays the status of node applications.
Syntax
srvctl status nodeapps [-node node_name]
Usage Notes
- You can only use this command with Oracle Clusterware.
- Optionally, you can specify a node for which to display the status of the node applications.
srvctl stop nodeapps
Stops node-level applications on a node in the cluster.
Syntax
srvctl stop nodeapps [-node node_name] [-onsonly] [-adminhelper] [-force]
[-relocate] [-verbose]
Parameters
Table: srvctl stop nodeapps Command Parameters
| Parameter | Description |
|---|---|
-node node_name | Optionally, you can use this parameter to specify a node on which you want to stop node applications. If you do not use this parameter, then the utility stops the node applications on all active nodes in the cluster. |
-onsonly | Optionally, you can use this parameter to disable only the Oracle Notification Service (ONS). |
-adminhelper | Optionally, you can use this parameter to stop only the Administrator helper instead of all node applications. |
-force | Optionally, you can use this parameter to stop node applications regardless of any dependencies. |
-relocate | Optionally, you can use this parameter to relocate the VIP and possibly-dependent services. Note: If you use this parameter, then you must also specify the |
-verbose | Optionally, you can use this parameter to display detailed output. |
Usage Notes
You can only use this command with Oracle Clusterware.
srvctl unsetenv nodeapps
Unsets the environment configuration for the node applications.
Syntax
srvctl unsetenv nodeapps -envs "name_list" [-viponly] [-onsonly]
[-verbose]
Parameters
Table: srvctl unsetenv nodeapps Command Parameters
| Parameter | Description |
|---|---|
-envs " name_list " | Specify a comma-delimited list of the names of environment variables enclosed in double quotation marks ( "" ) that you want to unset. |
-viponly | Optionally, you can use this parameter to unset only the VIP configuration. |
-onsonly | Optionally, you can use this parameter to unset only the ONS daemon configuration. |
-verbose | Optionally, you can use this parameter to display detailed output. |
Example
The following example unsets the environment configuration for the specified node applications:
$ srvctl unsetenv nodeapps -envs "test_var1,test_var2"